@@ -15,6 +15,12 @@
 
 #include "simdef.h"
 
+#if defined(WIN32)
+#define MSBMASK 0x8000000000000000I64
+#else
+#define MSBMASK 0x8000000000000000ULL
+#endif
+
 extern uint16 pcreg;	/* The program PC */
 extern uint16 opcreg;	/* The old program PC */
 extern uint16 statreg;	/* The program status register */
@@ -858,8 +864,8 @@ chkaddquad (t_int64 acc, t_int64 sv1, t_int64 sv2)
 
    if (acc < sv1) SET_CARRY;
 
-   if (((sv1 & 0x8000000000000000ULL) == (sv2 & 0x8000000000000000ULL)) &&
-       ((sv2 & 0x8000000000000000ULL) != (acc & 0x8000000000000000ULL)))
+   if (((sv1 & MSBMASK) == (sv2 & MSBMASK)) &&
+       ((sv2 & MSBMASK) != (acc & MSBMASK)))
        SET_OVER;
 }
 
@@ -891,8 +897,8 @@ chksubquad (t_int64 acc, t_int64 sv1, t_int64 sv2)
 
    if ((t_uint64)sv2 >= (t_uint64)sv1) SET_CARRY;
 
-   if (((sv1 & 0x8000000000000000ULL) != (sv2 & 0x8000000000000000ULL)) &&
-       ((sv2 & 0x8000000000000000ULL) != (acc & 0x8000000000000000ULL)))
+   if (((sv1 & MSBMASK) != (sv2 & MSBMASK)) &&
+       ((sv2 & MSBMASK) != (acc & MSBMASK)))
        SET_OVER;
 }
 
